@@ -32,13 +32,11 @@ def setup_logging(verbose=False):
 def resolvepath(path):
     """Resolve and normalize a path
 
-    1.  Handle tilde expansion; turn ~/.ssh into /home/user/.ssh and
-        ~otheruser/bin to /home/otheruser/bin
-    2.  Normalize the path so that it doesn't contain relative segments, turning
+    1.  Normalize the path so that it doesn't contain relative segments, turning
         e.g. /usr/local/../bin to /usr/bin
-    3.  Get the real path of the actual file, resolving symbolic links
+    2.  Get the real path of the actual file, resolving symbolic links
     """
-    return os.path.realpath(os.path.normpath(os.path.expanduser(path)))
+    return os.path.realpath(os.path.normpath(path))
 
 
 def parse_args(args):
@@ -81,25 +79,17 @@ def parse_args(args):
     parser_hash.set_defaults(func=run_hash)
 
     parser_hash.add_argument(
-        "-d",
-        "--dupfile",
+        "-f",
+        "--dbfile",
         type=resolvepath,
-        dest="dupfile",
-        default="duplicates.json",
-        help="Destination file for duplicated hashes. Must be a JSON file. Default: duplicates.json",
-    )
-    parser_hash.add_argument(
-        "-u",
-        "--unfile",
-        type=resolvepath,
-        dest="unfile",
-        default="uniques.json",
-        help="Destination file for unique hashes. Must be a JSON file. Default: uniques.json",
+        dest="dbfile",
+        default="file_hashes.json",
+        help="Destination database for file hashes. Must be a JSON file. Default: file_hashes.json",
     )
     parser_hash.add_argument(
         "--restart",
         action="store_true",
-        help="Restart a run of hashing files and skip over files that have already been hashed. Output files containing duplicated and unique filenames must already exist.",
+        help="Restart a run of hashing files and skip over files that have already been hashed. Output file containing a database of filenames and hashes must already exist.",
     )
 
     # Compare subcommand
@@ -111,11 +101,11 @@ def parse_args(args):
     parser_compare.set_defaults(func=run_compare)
 
     parser_compare.add_argument(
-        "-i",
+        "-f",
         "--infile",
         type=resolvepath,
-        default="duplicates.json",
-        help="Filename to analyse. Must be a JSON file. Default: duplicates.json",
+        default="file_hashes.json",
+        help="Database to analyse. Must be a JSON file. Default: file_hashes.json",
     )
     parser_compare.add_argument(
         "--purge", action="store_true", help="Deletes duplicated files. Default: False"
@@ -135,12 +125,21 @@ def parse_args(args):
 def main():
     args = parse_args(sys.argv[1:])
 
-    for file_arg in ["infile", "dupfile", "unfile"]:
+    for file_arg in ["infile", "dbfile"]:
         if (file_arg in vars(args).keys()) and not (
             vars(args)[file_arg].endswith(".json")
         ):
             raise ValueError("Please provide a JSON input file!")
 
+    if (args.command == "hash") and os.path.exists(args.dbfile) and not args.restart:
+        logging.warn("Starting a new run, deleting old database: %s" % args.dbfile)
+        os.remove(args.dbfile)
+    elif (args.command == "hash") and args.restart and not os.path.exists(args.dbfile):
+        raise FileNotFoundError(
+            "Trying to restart a run but cannot find the database file! "
+            + f"Is the filepath correct? {args.dbfile}"
+        )
+
     if args.count > CPUS:
         raise ValueError(
             "You have requested more threads than are available to this machine. "
